%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File: exemple_Eagle_1984.m
% Author: Michael Morin
% Last modified on: May 29, 2011
% Description:
%  An OSP example with a Markovian search object's motion model
% Reference: 
%  - J.N. Eagle, "The Optimal Search for a Moving Target when the Search 
%    Path is Constrained," Operations Research, vol. 32, no. 5, pp.
%    1107-1115, 1984.
%    
isOjbectMovingAtTime0 = 0; % See OspApplySearchPlan
searcherStartingRegion = 1; % A region in {1, 2, ..., 9}
    % Anything else corresponds will apply the motion model without
    % searching.

% Do not modify anything beyond this point.
T = 10;
W = 3;
H = 3;
N = W*H;
poc = zeros(1,N); % The object starts in the middle of the grid.
poc(9) = 1.0;
pod = 1.0;
D_s_s = 0.4 % D(s,s) = the probability that the object stay in the same
             % region.

D = OspGenerateMotionModel(D_s_s,W,H);

% y[t,r] = 1 <=> One discrete effort unit is assigned to region r at 
% time t
if(searcherStartingRegion == 1)
    Y = [ unitvec(2,N)' ;
          unitvec(3,N)' ;
          unitvec(6,N)' ;
          unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 1
elseif(searcherStartingRegion == 2)
    Y = [ unitvec(3,N)' ;
          unitvec(6,N)' ;
          unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 2
elseif(searcherStartingRegion == 3)
    Y = [ unitvec(3,N)' ;
          unitvec(6,N)' ;
          unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 3
elseif(searcherStartingRegion == 4)
    Y = [ unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 4
elseif(searcherStartingRegion == 5)
    Y = [ unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 5
elseif(searcherStartingRegion == 6)
    Y = [ unitvec(9,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ]; % An optimal search plan for y_0 = 6
elseif(searcherStartingRegion == 7)
    Y = [ unitvec(7,N)' ;
          unitvec(8,N)' ;
          unitvec(9,N)' ;
          unitvec(6,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ;
          unitvec(8,N)' ;
          unitvec(5,N)' ;
          unitvec(6,N)' ;
          unitvec(5,N)' ]; % An optimal search plan for y_0 = 7
elseif(searcherStartingRegion == 8)
    Y = [ unitvec(9,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ;
          unitvec(8,N)' ]; % An optimal search plan for y_0 = 8
elseif(searcherStartingRegion == 9)
    Y = [ unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ;
          unitvec(9,N)' ]; % An optimal search plan for y_0 = 9
else
    Y = zeros(T,N);
end
  
e_POC = OspApplySearchPlan(poc, D, pod, Y, isOjbectMovingAtTime0);

e_POC

TraceExtendedPoc(e_POC);
  
