%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File: exemple_Lau_et_al_2008.m
% Author: Michael Morin
% Last modified on: May 29, 2011
% Description:
%  An OSP example with a Markovian search object's motion model
% Reference: 
%  - H. Lau, S. Huang, and G. Dissanayake, "Discounted MEAN Bound for the
%    Optimal Searcher Path Problem with Non-Uniform Travel Times,"
%    European journal of operational research, vol. 190, no. 2, 
%    pp. 383-397, 2008.
%
isOjbectMovingAtTime0 = 0; % See OspApplySearchPlan
dontSearch = 0; % 0 => Apply an optimal search plan, 1 => don't search
% Do not modify anything beyond this point.
T = 15;
W = 11;
H = 11;
N = W*H;
poc = zeros(1,N); % The object starts in the middle of the grid.
poc(61) = 1.0;
pod = 0.6;
D_s_s = 0.6; % D(s,s) = the probability that the object stay in the same
             % region.

D = OspGenerateMotionModel(D_s_s,W,H);

% y[t,r] = 1 <=> One discrete effort unit is assigned to region r at 
% 5time t
if(dontSearch == 0)
    Y = [ unitvec(2,N)' ;
          unitvec(3,N)' ;
          unitvec(4,N)' ;
          unitvec(15,N)' ;
          unitvec(26,N)' ;
          unitvec(37,N)' ;
          unitvec(48,N)' ;
          unitvec(49,N)' ;
          unitvec(60,N)' ;
          unitvec(61,N)' ;
          unitvec(72,N)' ;
          unitvec(73,N)' ;
          unitvec(62,N)' ;
          unitvec(61,N)' ;
          unitvec(50,N)' ]; % An optimal search plan for y_0 = 1
else
    Y = zeros(T,N);
end
  
e_POC = OspApplySearchPlan(poc, D, pod, Y, isOjbectMovingAtTime0);

e_POC

TraceExtendedPoc(e_POC);
